==> jc-1.4.0.tar.gz: gnu/java/nio/VMPipe.h <==
// final class gnu.java.nio.VMPipe

// class file dependencies
// @dep_class d1793d33f2e26a3a gnu_java_nio_VMPipe
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_nio_VMPipe_H_
#define _JC_gnu_java_nio_VMPipe_H_

// Forward structure declarations
struct _jc_gnu_java_nio_PipeImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_gnu_java_nio_VMPipe$sub_refs	_jc_gnu_java_nio_VMPipe$sub_refs;
typedef struct _jc_gnu_java_nio_VMPipe$sub_nonrefs	_jc_gnu_java_nio_VMPipe$sub_nonrefs;
typedef struct _jc_gnu_java_nio_VMPipe$refs	_jc_gnu_java_nio_VMPipe$refs;
typedef struct _jc_gnu_java_nio_VMPipe$nonrefs	_jc_gnu_java_nio_VMPipe$nonrefs;
typedef struct _jc_gnu_java_nio_VMPipe$object	_jc_gnu_java_nio_VMPipe$object;

typedef const struct _jc_gnu_java_nio_VMPipe$vmethods	_jc_gnu_java_nio_VMPipe$vmethods;
typedef const struct _jc_gnu_java_nio_VMPipe$vtable	_jc_gnu_java_nio_VMPipe$vtable;
typedef const struct _jc_gnu_java_nio_VMPipe$vtype	_jc_gnu_java_nio_VMPipe$vtype;

// Constructors
extern void _jc_gnu_java_nio_VMPipe$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_VMPipe$object *);

// Static methods
extern void _jc_gnu_java_nio_VMPipe$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_gnu_java_nio_VMPipe$method$init$5f5fbe65e14008f6(_jc_env *, struct _jc_gnu_java_nio_PipeImpl$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);

// Virtual methods structure
struct _jc_gnu_java_nio_VMPipe$vmethods {
};

// Vtable
struct _jc_gnu_java_nio_VMPipe$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_nio_VMPipe$vmethods	gnu_java_nio_VMPipe;
};

// Vtype
struct _jc_gnu_java_nio_VMPipe$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_VMPipe$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_VMPipe$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_VMPipe$refs {
    _jc_gnu_java_nio_VMPipe$sub_refs	gnu_java_nio_VMPipe;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_VMPipe$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_VMPipe$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_nio_VMPipe$sub_nonrefs	gnu_java_nio_VMPipe;
};

// Object instance structure
struct _jc_gnu_java_nio_VMPipe$object {
	_jc_gnu_java_nio_VMPipe$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_VMPipe$vtype	*vtype;
	_jc_gnu_java_nio_VMPipe$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_VMPipe$vtype _jc_gnu_java_nio_VMPipe$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_VMPipe, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_VMPipe$class_object;

#endif	/* _JC_gnu_java_nio_VMPipe_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/VMPipe.h <==
// final class gnu.java.nio.VMPipe

// class file dependencies
// @dep_class d1793d33f2e26a3a gnu_java_nio_VMPipe
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_nio_VMPipe_H_
#define _JC_gnu_java_nio_VMPipe_H_

// Forward structure declarations
struct _jc_gnu_java_nio_PipeImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_gnu_java_nio_VMPipe$sub_refs	_jc_gnu_java_nio_VMPipe$sub_refs;
typedef struct _jc_gnu_java_nio_VMPipe$sub_nonrefs	_jc_gnu_java_nio_VMPipe$sub_nonrefs;
typedef struct _jc_gnu_java_nio_VMPipe$refs	_jc_gnu_java_nio_VMPipe$refs;
typedef struct _jc_gnu_java_nio_VMPipe$nonrefs	_jc_gnu_java_nio_VMPipe$nonrefs;
typedef struct _jc_gnu_java_nio_VMPipe$object	_jc_gnu_java_nio_VMPipe$object;

typedef const struct _jc_gnu_java_nio_VMPipe$vmethods	_jc_gnu_java_nio_VMPipe$vmethods;
typedef const struct _jc_gnu_java_nio_VMPipe$vtable	_jc_gnu_java_nio_VMPipe$vtable;
typedef const struct _jc_gnu_java_nio_VMPipe$vtype	_jc_gnu_java_nio_VMPipe$vtype;

// Constructors
extern void _jc_gnu_java_nio_VMPipe$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_VMPipe$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_java_nio_VMPipe$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_VMPipe$method$init$5f5fbe65e14008f6(_jc_env *, struct _jc_gnu_java_nio_PipeImpl$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_nio_VMPipe$vmethods {
};

// Vtable
struct _jc_gnu_java_nio_VMPipe$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_nio_VMPipe$vmethods	gnu_java_nio_VMPipe;
};

// Vtype
struct _jc_gnu_java_nio_VMPipe$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_VMPipe$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_VMPipe$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_VMPipe$refs {
    _jc_gnu_java_nio_VMPipe$sub_refs	gnu_java_nio_VMPipe;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_VMPipe$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_VMPipe$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_nio_VMPipe$sub_nonrefs	gnu_java_nio_VMPipe;
};

// Object instance structure
struct _jc_gnu_java_nio_VMPipe$object {
	_jc_gnu_java_nio_VMPipe$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_VMPipe$vtype	*vtype;
	_jc_gnu_java_nio_VMPipe$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_VMPipe$vtype _jc_gnu_java_nio_VMPipe$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_VMPipe, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_VMPipe$class_object;

#endif	/* _JC_gnu_java_nio_VMPipe_H_ */
